@@ -269,7 +269,7 @@ class Test_sqlitebiter_file:
                     table, expected_data, actual_data
                 )
 
-                print("--- table: {} ---".format(table))
+                print(f"--- table: {table} ---")
                 print_test_result(expected=expected_data, actual=actual_data)
 
                 assert sorted(expected_data) == sorted(actual_data), message
@@ -305,15 +305,15 @@ class Test_sqlitebiter_file:
                     """\
                     .. table:: valid_csv_3_1
 
-                        +-----+-------+----+---+-------+-----+-----+
-                        |Field| Type  |Null|Key|Default|Index|Extra|
-                        +=====+=======+====+===+=======+=====+=====+
-                        |aa   |REAL   |YES |   |NULL   |  X  |     |
-                        +-----+-------+----+---+-------+-----+-----+
-                        |ab   |INTEGER|YES |   |NULL   |     |     |
-                        +-----+-------+----+---+-------+-----+-----+
-                        |ac   |TEXT   |YES |   |NULL   |  X  |     |
-                        +-----+-------+----+---+-------+-----+-----+
+                        +-------+---------+------+-----+---------+-------+-------+
+                        | Field |  Type   | Null | Key | Default | Index | Extra |
+                        +=======+=========+======+=====+=========+=======+=======+
+                        | aa    | REAL    | YES  |     | NULL    |   X   |       |
+                        +-------+---------+------+-----+---------+-------+-------+
+                        | ab    | INTEGER | YES  |     | NULL    |       |       |
+                        +-------+---------+------+-----+---------+-------+-------+
+                        | ac    | TEXT    | YES  |     | NULL    |   X   |       |
+                        +-------+---------+------+-----+---------+-------+-------+
                     """
                 ),
             ]
@@ -488,7 +488,7 @@ class Test_sqlitebiter_file:
                     table, expected_data, actual_data
                 )
 
-                print("--- table: {} ---".format(table))
+                print(f"--- table: {table} ---")
                 print_test_result(expected=expected_data, actual=actual_data)
 
                 assert expected_data == actual_data, message
@@ -528,7 +528,7 @@ class Test_sqlitebiter_file:
                     table, expected_data, actual_data
                 )
 
-                print("--- table: {} ---".format(table))
+                print(f"--- table: {table} ---")
                 print_test_result(expected=expected_data, actual=actual_data)
 
                 assert actual_data == expected_data, message
@@ -572,8 +572,8 @@ class Test_sqlitebiter_file:
     def test_normal_type_hint_header(self):
         runner = CliRunner()
         basename = "type_hint_header"
-        file_path = "{}.csv".format(basename)
-        db_path = "{}.sqlite".format(basename)
+        file_path = f"{basename}.csv"
+        db_path = f"{basename}.sqlite"
 
         with runner.isolated_filesystem():
             with open(file_path, "w") as f:
@@ -581,9 +581,9 @@ class Test_sqlitebiter_file:
                     dedent(
                         """\
                         "a text","b integer","c real"
-                        1,"1","1.1"
+                        01,"01","1.1"
                         2,"2","1.2"
-                        3,"3","1.3"
+                        03,"03","1.3"
                         """
                     )
                 )
@@ -596,13 +596,17 @@ class Test_sqlitebiter_file:
             con = SimpleSQLite(db_path, "r")
             tbldata = con.select_as_tabledata(basename)
             assert tbldata.headers == ["a text", "b integer", "c real"]
-            assert tbldata.rows == [("1", 1, 1.1), ("2", 2, 1.2), ("3", 3, 1.3)]
+            assert tbldata.rows == [
+                ("01", 1, 1.1),
+                ("2", 2, 1.2),
+                ("03", 3, 1.3),
+            ]
 
     def test_normal_add_primary_key(self):
         runner = CliRunner()
         basename = "add_primary_key"
-        file_path = "{}.csv".format(basename)
-        db_path = "{}.sqlite".format(basename)
+        file_path = f"{basename}.csv"
+        db_path = f"{basename}.sqlite"
 
         with runner.isolated_filesystem():
             with open(file_path, "w") as f:
@@ -631,8 +635,8 @@ class Test_sqlitebiter_file:
     def test_normal_no_type_inference(self):
         runner = CliRunner()
         basename = "no_type_inference"
-        file_path = "{}.csv".format(basename)
-        db_path = "{}.sqlite".format(basename)
+        file_path = f"{basename}.csv"
+        db_path = f"{basename}.sqlite"
 
         with runner.isolated_filesystem():
             with open(file_path, "w") as f:
@@ -640,7 +644,7 @@ class Test_sqlitebiter_file:
                     dedent(
                         """\
                         "a","b"
-                        11,"xyz"
+                        011,"xyz"
                         22,"abc"
                         """
                     )
@@ -654,7 +658,10 @@ class Test_sqlitebiter_file:
             con = SimpleSQLite(db_path, "r")
             tbldata = con.select_as_tabledata(basename)
             assert tbldata.headers == ["a", "b"]
-            assert tbldata.rows == [("11", "xyz"), ("22", "abc")]
+            assert tbldata.rows == [
+                ("011", "xyz"),
+                ("22", "abc"),
+            ]
 
     def test_smoke_max_workers(self):
         db_path = "test.sqlite"
